@@ -23,11 +23,9 @@
 #' @param \dots further arguments and graphical parameters passed to
 #' \code{\link{plot.default}}. See details for further information
 #'
-#' @return This function returns an Rlum.Results object of the RF/RL simulation.
+#' @return This function returns an RLum.Results object of the RF/RL simulation.
 #'
-#' @note This function can do just nothing at the moment.
-#'
-#' @section Function version: 0.1.1
+#' @section Function version: 0.1.2 [2016-09-02]
 #'
 #' @author Johannes Friedrich, University of Bayreuth (Germany),
 #'
@@ -92,24 +90,32 @@
 
 # Set parameters for ODE ---------------------------------------------------
 
-  ##============================================================================##
+    ##============================================================================##
   # SETTING PARAMETERS FOR IRRADIATION
   #
   # R: electron-hole-production-rate (in Bailey 2004: 2.5e10, else: 5e7)
   # P: Photonflux (in Bailey 2004: wavelength [nm])
   # b: heating rate [deg. C/s]
   ##============================================================================##
-  if(parms$model == "Bailey2004"){
-    R <- dose_rate*2.5e10
-  } else {
+  ## check if R is given in customized parameter sets
+  if("R" %in% names(parms) && parms$R != 0){
     
-    if(parms$model == "Bailey2002"){
-      R <- dose_rate*3e10
+    R <- dose_rate*parms$R
+    
+  } else {
+  
+    if(parms$model == "Bailey2004"){
+      R <- dose_rate*2.5e10
     } else {
-    R <- dose_rate*5e7  # all other simulations
+      
+      if(parms$model == "Bailey2002"){
+        R <- dose_rate*3e10
+      } else {
+        R <- dose_rate*5e7  # all other simulations
+      }
     }
   }
- 
+  
   P <- 0
   b <- 0
 
@@ -117,13 +123,21 @@
   # SETTING PARAMETERS FOR ODE
   ##============================================================================##
 
-  times   <- seq(0, dose/(dose_rate), by = (dose/dose_rate)/100)
-  parameters.step  <- list(R = R, P = P, temp = temp, b = b, times = times, parms = parms)
-
+  times   <- seq(0, dose/(dose_rate), by = (dose/dose_rate)/1000)
+  parameters.step <- .extract_pars(parameters.step = list(
+    R = R,
+    P = P,
+    temp = temp,
+    b = b,
+    times = times,
+    parms = parms))
+  
+  if(dose != 0){
+  
   ##============================================================================##
   # SOLVING ODE (deSolve requiered)
   ##============================================================================##
-  out <- deSolve::lsoda(y = n, times = times, parms = parameters.step, func = .set_ODE ,  rtol=1e-3, atol=1e-3, maxsteps=1e5);
+  out <- deSolve::lsoda(y = n, times = times, parms = parameters.step, func = .set_ODE_Rcpp, rtol = 1e-4, atol = 1e-4,maxsteps = 10000)
 
   ##============================================================================##
   # CALCULATING RESULTS FROM ODE SOLVING
@@ -131,7 +145,6 @@
 
   signal <- .calc_signal(object = out, parameters = parameters.step)
 
-
   ##============================================================================##
   # CALCULATING CONCENTRATIONS FROM ODE SOLVING
   ##============================================================================##
@@ -148,18 +161,42 @@
   ##============================================================================##
 
   return(Luminescence::set_RLum(class = "RLum.Results",
-                  data = list(
-                    n = out[length(times), -1],
-                    RF.data = Luminescence::set_RLum(
-                      class = "RLum.Data.Curve",
-                      data = matrix(data = c(times, signal), ncol = 2),
-                      recordType = "RF",
-                      curveType = "simulated",
-                      info = list(RLumModel_ID = RLumModel_ID)
-                    ),
-                    temp = temp,
-                    concentrations = concentrations)
+                                data = list(
+                                n = out[length(times), -1],
+                                RF.data = Luminescence::set_RLum(
+                                  class = "RLum.Data.Curve",
+                                  data = matrix(data = c(times, signal), ncol = 2),
+                                  recordType = "RF",
+                                  curveType = "simulated",
+                                  info = list(
+                                    curveDescripter = NA_character_),
+                                    .pid = as.character(RLumModel_ID)
+                                  ),
+                                  temp = temp,
+                                  concentrations = concentrations)
                   )
          )
 
+  } else { ## dose == 0
+    
+    return(Luminescence::set_RLum(class = "RLum.Results",
+                                  data = list(
+                                    n = n,
+                                    RF.data = Luminescence::set_RLum(
+                                      class = "RLum.Data.Curve",
+                                      data = matrix(data = c(times, 0), ncol = 2),
+                                      recordType = "RF",
+                                      curveType = "simulated",
+                                      info = list(
+                                        curveDescripter = NA_character_
+                                        ),
+                                      .pid = as.character(RLumModel_ID)
+                                    ),
+                                    temp = temp,
+                                    concentrations = NULL)
+                                  )
+    )
+    
+    
+  }
 }
