@@ -16,10 +16,8 @@
 #' @param \dots further arguments and graphical parameters passed to
 #' \code{\link{plot.default}}. See details for further information
 #'
-#' @return This function returns an Rlum.Results object from the illumination simulation.
-#'
-#' @note This function can do just nothing at the moment.
-#'
+#' @return This function returns an RLum.Results object from the illumination simulation.
+#' 
 #' @section Function version: 0.1.1
 #'
 #' @author Johannes Friedrich, University of Bayreuth (Germany),
@@ -76,7 +74,6 @@
   ##============================================================================##
 
   if(parms$model == "Bailey2004" || parms$model == "Bailey2002"){
- 
     P <- 0.02/(1.6*10^(-19)*(1240/470))*(optical_power/100)
   }
   else{
@@ -91,13 +88,17 @@
   ##============================================================================##
 
   times <- seq(0, duration, by = duration/100)
-  parameters.step  <- list(R = R, P = P, temp = temp, b = b, times = times, parms = parms)
-
+  parameters.step <- .extract_pars(parameters.step = list(
+    R = R,
+    P = P,
+    temp = temp,
+    b = b,
+    times = times,
+    parms = parms))
   ##============================================================================##
   # SOLVING ODE (deSolve requiered)
   ##============================================================================##
-  out <- deSolve::ode(y = n, times = times, parms = parameters.step, func = .set_ODE, rtol=1e-3, atol=1e-3, maxsteps=1e5, method = "bdf");
-  
+  out <- deSolve::ode(y = n, times = times, parms = parameters.step, func = .set_ODE_Rcpp, rtol=1e-3, atol=1e-3, maxsteps=1e5, method = "bdf")
   ##============================================================================##
 
   ##============================================================================##
